@@ -20,7 +20,6 @@ from google.api_core import gapic_v1  # type: ignore
 from google.api_core import grpc_helpers_async  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-import packaging.version
 
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
@@ -446,5 +445,8 @@ class TranscoderServiceGrpcAsyncIOTransport(TranscoderServiceTransport):
             )
         return self._stubs["delete_job_template"]
 
+    def close(self):
+        return self.grpc_channel.close()
+
 
 __all__ = ("TranscoderServiceGrpcAsyncIOTransport",)
